| Title: | Efficiencies of Block Designs for Factorial and Fractional Factorial Experiments |
|---|---|
| Description: | Opens a 'shiny' app which supports theoretical and computational analysis of block designs for symmetrical and mixed level factorial experiments. This package includes tools to check whether a design has orthogonal factorial structure (OFS) with balance or not and is able to find the orthogonality deviation value if not having OFS. This package includes function to evaluate efficiency factor of all factorial effects in two situations, in the first situation if the design is verified with OFS and balance then calculate the efficiencies of all factorial effects using a specific analytical procedure and in the second situation if the design is verified with non-OFS and balance then a new general method has been developed and used to calculate efficiencies under the condition that the design should be proper and equi-replicated, See Gupta, S.C. and Mukerjee, R. (1987): "A Calculus for factorial arrangements". Lecture Notes in Statistics. No. 59, Springer-Verlag, Berlin, New York, <doi:10.1007/978-1-4419-8730-3>. For the easy use of package, 'shiny' app is used for giving inputs and inputs validation. |
| Authors: | Sukanta Dash [aut], Baidya Nath Mandal [aut, cre], Anil Kumar [aut] |
| Maintainer: | Baidya Nath Mandal <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-27 07:18:47 UTC |
| Source: | https://github.com/cran/FactEff |
Returns factorial designs properties such as block sizes, replications of treatments, orthogonal factorial structure or not, efficiencies of main effects and interactions
analyze_design(factor_levels, blocks)analyze_design(factor_levels, blocks)
factor_levels |
a numeric vector with positive entries, elements denoting levels of factors |
blocks |
a list of numeric vectors of same size, each vector representing individual block contents of a factorial design. |
Returns factorial designs properties such as block sizes, replications of treatments, orthogonal factorial structure or not, efficiencies of main effects and interactions
blocks = as.matrix(autogenerate_design(2,c(3,4),3,2)) blocks = lapply(seq_len(ncol(blocks)), function(i) blocks[, i]) analyze_design(c(3,4), blocks)blocks = as.matrix(autogenerate_design(2,c(3,4),3,2)) blocks = lapply(seq_len(ncol(blocks)), function(i) blocks[, i]) analyze_design(c(3,4), blocks)
Autogenerate a blocked factorial design for given number of factors, factor levels, block size and replications
autogenerate_design(n_factors, factor_levels, block_size, replications)autogenerate_design(n_factors, factor_levels, block_size, replications)
n_factors |
a positive integer, denoting number of factors |
factor_levels |
a numeric vector with positive entries with length same as n_factors, elements denoting levels of factors |
block_size |
a positive integer, denoting block size |
replications |
a positive integer, denoting number of replications |
Returns a blocked factorial design with columns representing blocks and entries representing treatment combinations
autogenerate_design(2,c(3,4),3,2)autogenerate_design(2,c(3,4),3,2)
opens a 'shiny' interface where user can provide necessary inputs to analyze a factorial design
run_app()run_app()
opens shiny interface with input and output areas
if(interactive()) run_appif(interactive()) run_app